# yodlee ![Build Status](https://travis-ci.org/cogolabs/yodlee.svg) [![PyPI version](https://badge.fury.io/py/yodlee.svg)](https://badge.fury.io/py/yodlee)
Evestnet Yodlee API Client

## Installation

```
pip install yodlee
```

## Development

- Run `pip install -r requirements.txt` to install dependencies.
- Run `python test` to run the tests.

## Contributing

We are happy to receive your contribution if you will first please complete our [Contributor License Agreement](https://github.com/cogolabs/about/CLA.pdf).

## License

The package is available as open source under the terms of the [Apache 2 License](LICENSE.txt).
